pub struct RetryLayer { /* private fields */ }Expand description
Retry middleware.
When the inner application returns a response whose status code is in the
configured list, the request is re-dispatched up to max_retries additional
times. If all attempts return a retryable status the last response is
returned as-is.
Implementations
Sourceimpl RetryLayer
impl RetryLayer