Module compression

Module compression 

Functions

apply_gzip
If the client accepts gzip and the response body is compressible text, compress every content range in-place and add Content-Encoding: gzip. Also appends Accept-Encoding to the Vary header.