pub fn current() -> ConfigSnapshotExpand description
Returns a clone of the current hot-reloadable configuration snapshot.
This takes a brief read lock and clones a handful of strings — safe to call on every request if needed.
pub fn current() -> ConfigSnapshotReturns a clone of the current hot-reloadable configuration snapshot.
This takes a brief read lock and clones a handful of strings — safe to call on every request if needed.