Config

Struct Config 

pub struct Config {}

Implementations

Source

impl Config

pub const RWS_CONFIG_IP: &'static str = "RWS_CONFIG_IP"

pub const RWS_CONFIG_IP_DEFAULT_VALUE: &'static str = "0.0.0.0"

Default is 0.0.0.0 so the server is reachable inside containers and K8s pods. For local development you can override to 127.0.0.1 via env var or config file.

pub const RWS_CONFIG_LOG_FORMAT: &'static str = "RWS_CONFIG_LOG_FORMAT"

Log format: "combined" (default, Combined Log Format) or "json" (structured JSON).

pub const RWS_CONFIG_LOG_FORMAT_DEFAULT_VALUE: &'static str = "json"

pub const RWS_CONFIG_PORT: &'static str = "RWS_CONFIG_PORT"

pub const RWS_CONFIG_PORT_DEFAULT_VALUE: &'static str = "7878"

pub const RWS_CONFIG_THREAD_COUNT: &'static str = "RWS_CONFIG_THREAD_COUNT"

pub const RWS_CONFIG_THREAD_COUNT_DEFAULT_VALUE: &'static str = "200"

pub const RWS_CONFIG_CORS_ALLOW_ALL: &'static str = "RWS_CONFIG_CORS_ALLOW_ALL"

pub const RWS_CONFIG_CORS_ALLOW_ALL_DEFAULT_VALUE: &'static str = "true"

pub const RWS_CONFIG_CORS_ALLOW_ORIGINS: &'static str = "RWS_CONFIG_CORS_ALLOW_ORIGINS"

pub const RWS_CONFIG_CORS_ALLOW_ORIGINS_DEFAULT_VALUE: &'static str = ""

pub const RWS_CONFIG_CORS_ALLOW_CREDENTIALS: &'static str = "RWS_CONFIG_CORS_ALLOW_CREDENTIALS"

pub const RWS_CONFIG_CORS_ALLOW_CREDENTIALS_DEFAULT_VALUE: &'static str = ""

pub const RWS_CONFIG_CORS_ALLOW_HEADERS: &'static str = "RWS_CONFIG_CORS_ALLOW_HEADERS"

pub const RWS_CONFIG_CORS_ALLOW_HEADERS_DEFAULT_VALUE: &'static str = ""

pub const RWS_CONFIG_CORS_ALLOW_METHODS: &'static str = "RWS_CONFIG_CORS_ALLOW_METHODS"

pub const RWS_CONFIG_CORS_ALLOW_METHODS_DEFAULT_VALUE: &'static str = ""

pub const RWS_CONFIG_CORS_EXPOSE_HEADERS: &'static str = "RWS_CONFIG_CORS_EXPOSE_HEADERS"

pub const RWS_CONFIG_CORS_EXPOSE_HEADERS_DEFAULT_VALUE: &'static str = ""

pub const RWS_CONFIG_CORS_MAX_AGE: &'static str = "RWS_CONFIG_CORS_MAX_AGE"

pub const RWS_CONFIG_CORS_MAX_AGE_DEFAULT_VALUE: &'static str = "86400"

pub const RWS_CONFIG_REQUEST_ALLOCATION_SIZE_IN_BYTES: &'static str = "RWS_CONFIG_REQUEST_ALLOCATION_SIZE_IN_BYTES"

pub const RWS_CONFIG_REQUEST_ALLOCATION_SIZE_IN_BYTES_DEFAULT_VALUE: &'static str = "10000"

pub const RWS_CONFIG_TLS_CERT_FILE: &'static str = "RWS_CONFIG_TLS_CERT_FILE"

pub const RWS_CONFIG_TLS_CERT_FILE_DEFAULT_VALUE: &'static str = ""

pub const RWS_CONFIG_TLS_KEY_FILE: &'static str = "RWS_CONFIG_TLS_KEY_FILE"

pub const RWS_CONFIG_TLS_KEY_FILE_DEFAULT_VALUE: &'static str = ""

pub const RWS_CONFIG_TLS_CLIENT_CA_FILE: &'static str = "RWS_CONFIG_TLS_CLIENT_CA_FILE"

Path to a PEM-encoded CA certificate used to verify client certificates (mTLS). When set, the TLS handshake requires a valid client certificate signed by this CA. Connections without a valid cert are rejected at the TLS layer (before any HTTP processing).

pub const RWS_CONFIG_TLS_CLIENT_CA_FILE_DEFAULT_VALUE: &'static str = ""

pub const RWS_CONFIG_TEMPLATE_DIR: &'static str = "RWS_CONFIG_TEMPLATE_DIR"

Directory containing Tera HTML templates (default: "templates"). Requires tera feature.

pub const RWS_CONFIG_TEMPLATE_DIR_DEFAULT_VALUE: &'static str = "templates"

pub const RWS_CONFIG_HTTP_REDIRECT_PORT: &'static str = "RWS_CONFIG_HTTP_REDIRECT_PORT"

When non-empty, a plain-HTTP listener on this port redirects all requests to HTTPS. Set to e.g. "80" when running on standard ports. Requires TLS to be configured.

pub const RWS_CONFIG_HTTP_REDIRECT_PORT_DEFAULT_VALUE: &'static str = ""

pub const RWS_CONFIG_ACME_DOMAINS: &'static str = "RWS_CONFIG_ACME_DOMAINS"

Comma-separated list of domain names to obtain a certificate for. Setting this activates ACME at startup. Example: "example.com,www.example.com"

pub const RWS_CONFIG_ACME_DOMAINS_DEFAULT_VALUE: &'static str = ""

pub const RWS_CONFIG_ACME_EMAIL: &'static str = "RWS_CONFIG_ACME_EMAIL"

Contact email sent to the CA. Recommended but not required.

pub const RWS_CONFIG_ACME_EMAIL_DEFAULT_VALUE: &'static str = ""

pub const RWS_CONFIG_ACME_STAGING: &'static str = "RWS_CONFIG_ACME_STAGING"

Set to "true" to use the Let’s Encrypt staging environment (for testing).

pub const RWS_CONFIG_ACME_STAGING_DEFAULT_VALUE: &'static str = "false"

pub const RWS_CONFIG_ACME_DIRECTORY: &'static str = "RWS_CONFIG_ACME_DIRECTORY"

Custom ACME directory URL. Defaults to Let’s Encrypt production.

pub const RWS_CONFIG_ACME_DIRECTORY_DEFAULT_VALUE: &'static str = ""

pub const RWS_CONFIG_ACME_CERT_PATH: &'static str = "RWS_CONFIG_ACME_CERT_PATH"

Where to write the provisioned certificate chain (PEM). Defaults to RWS_CONFIG_TLS_CERT_FILE.

pub const RWS_CONFIG_ACME_CERT_PATH_DEFAULT_VALUE: &'static str = ""

pub const RWS_CONFIG_ACME_KEY_PATH: &'static str = "RWS_CONFIG_ACME_KEY_PATH"

Where to write the certificate’s private key (PEM). Defaults to RWS_CONFIG_TLS_KEY_FILE.

pub const RWS_CONFIG_ACME_KEY_PATH_DEFAULT_VALUE: &'static str = ""

pub const RWS_CONFIG_ACME_CHALLENGE_PORT: &'static str = "RWS_CONFIG_ACME_CHALLENGE_PORT"

Port for the temporary HTTP-01 challenge server (default 80). Must be reachable from the internet on port 80. Not used with DNS-01.

pub const RWS_CONFIG_ACME_CHALLENGE_PORT_DEFAULT_VALUE: &'static str = "80"

pub const RWS_CONFIG_ACME_RENEW_BEFORE_DAYS: &'static str = "RWS_CONFIG_ACME_RENEW_BEFORE_DAYS"

Renew when fewer than this many days remain on the certificate (default 30).

pub const RWS_CONFIG_ACME_RENEW_BEFORE_DAYS_DEFAULT_VALUE: &'static str = "30"

pub const RWS_CONFIG_ACME_ACCOUNT_KEY_PATH: &'static str = "RWS_CONFIG_ACME_ACCOUNT_KEY_PATH"

Path to persist the ACME account key between restarts (default acme_account.key).

pub const RWS_CONFIG_ACME_ACCOUNT_KEY_PATH_DEFAULT_VALUE: &'static str = "acme_account.key"

pub const RWS_DEFAULT_IP: &'static str = "127.0.0.1"

pub const RWS_DEFAULT_PORT: &'static i32

pub const RWS_DEFAULT_THREAD_COUNT: &'static i32

pub const RWS_DEFAULT_REQUEST_ALLOCATION_SIZE_IN_BYTES: &'static i64