pub struct IngressRule {
pub host: String,
pub path: String,
pub path_type: PathType,
pub service_name: String,
pub service_port: u16,
pub namespace: String,
}Expand description
A single routing rule parsed from a Kubernetes Ingress resource.
Fields
host: StringValue of spec.rules[].host. Empty string means match-all.
path: StringValue of spec.rules[].http.paths[].path.
path_type: PathTypeValue of spec.rules[].http.paths[].pathType. Defaults to
PathType::Prefix if the field is absent.
service_name: StringKubernetes service name (spec.rules[].http.paths[].backend.service.name).
service_port: u16Kubernetes service port number.
namespace: StringNamespace the Ingress lives in.
Implementations
Sourceimpl IngressRule
impl IngressRule
Sourcepub fn upstream_addr(&self) -> String
pub fn upstream_addr(&self) -> String
Build the upstream Kubernetes DNS address.
Returns "{service_name}.{namespace}.svc.cluster.local:{service_port}".
Sourcepub fn matches(&self, host: &str, uri: &str) -> bool
pub fn matches(&self, host: &str, uri: &str) -> bool
Returns true if this rule matches the given host header value and
request uri.
- If
self.hostis non-empty, the incominghostmust match (case-insensitive). - Any query string on
uriis ignored for path matching. PathType::Exactrequires the request path to equalself.pathexactly.PathType::Prefix(andPathType::ImplementationSpecific) match on whole path segments —/foomatches/foo,/foo/, and/foo/bar, but not/foobar— not a raw byte prefix.