pub fn setup(config: TracingConfig)Expand description
Initialize tracing with an explicit config. Call once at startup before the server starts accepting requests.
Calling this more than once is a no-op (the first call wins).
pub fn setup(config: TracingConfig)Initialize tracing with an explicit config. Call once at startup before the server starts accepting requests.
Calling this more than once is a no-op (the first call wins).