pub fn build_from_file() -> (ConfigDrivenApp, Vec<JoinHandle<()>>)Expand description
Build a ConfigDrivenApp from rws.config.toml and spawn L4/WS proxy
threads. Returns the app and a list of background thread handles.
pub fn build_from_file() -> (ConfigDrivenApp, Vec<JoinHandle<()>>)Build a ConfigDrivenApp from rws.config.toml and spawn L4/WS proxy
threads. Returns the app and a list of background thread handles.