pub fn is_email(s: &str) -> bool
Returns true if s is a plausible email address.
true
s
Checks for a non-empty local part, exactly one @, and a domain that contains at least one . and does not start or end with ..
@
.